@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import ComponentTypeType, OwnershipType, PipelineStatusType, PlatformType
 from .type_defs import (
@@ -115,20 +115,25 @@ class Exceptions:
     ServiceUnavailableException: Type[BotocoreClientError]
 
 
-class imagebuilderClient:
+class imagebuilderClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        imagebuilderClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#can_paginate)
         """
 
@@ -138,7 +143,7 @@ class imagebuilderClient:
         """
         CancelImageCreation cancels the creation of Image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.cancel_image_creation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.cancel_image_creation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#cancel_image_creation)
         """
 
@@ -161,7 +166,7 @@ class imagebuilderClient:
         Creates a new component that can be used to build, validate, test, and assess
         your image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.create_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.create_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_component)
         """
 
@@ -188,7 +193,7 @@ class imagebuilderClient:
         """
         Creates a new container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.create_container_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.create_container_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_container_recipe)
         """
 
@@ -204,7 +209,7 @@ class imagebuilderClient:
         """
         Creates a new distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.create_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.create_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_distribution_configuration)
         """
 
@@ -223,7 +228,7 @@ class imagebuilderClient:
         """
         Creates a new image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.create_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.create_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_image)
         """
 
@@ -246,7 +251,7 @@ class imagebuilderClient:
         """
         Creates a new image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.create_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.create_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_image_pipeline)
         """
 
@@ -266,7 +271,7 @@ class imagebuilderClient:
         """
         Creates a new image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.create_image_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.create_image_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_image_recipe)
         """
 
@@ -290,7 +295,7 @@ class imagebuilderClient:
         """
         Creates a new infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.create_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.create_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_infrastructure_configuration)
         """
 
@@ -298,7 +303,7 @@ class imagebuilderClient:
         """
         Deletes a component build version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.delete_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.delete_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_component)
         """
 
@@ -308,7 +313,7 @@ class imagebuilderClient:
         """
         Deletes a container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.delete_container_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.delete_container_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_container_recipe)
         """
 
@@ -318,7 +323,7 @@ class imagebuilderClient:
         """
         Deletes a distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.delete_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.delete_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_distribution_configuration)
         """
 
@@ -326,7 +331,7 @@ class imagebuilderClient:
         """
         Deletes an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.delete_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.delete_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_image)
         """
 
@@ -334,7 +339,7 @@ class imagebuilderClient:
         """
         Deletes an image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_image_pipeline)
         """
 
@@ -342,7 +347,7 @@ class imagebuilderClient:
         """
         Deletes an image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_image_recipe)
         """
 
@@ -352,7 +357,7 @@ class imagebuilderClient:
         """
         Deletes an infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.delete_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.delete_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_infrastructure_configuration)
         """
 
@@ -366,7 +371,7 @@ class imagebuilderClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#generate_presigned_url)
         """
 
@@ -374,7 +379,7 @@ class imagebuilderClient:
         """
         Gets a component object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.get_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.get_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_component)
         """
 
@@ -382,7 +387,7 @@ class imagebuilderClient:
         """
         Gets a component policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.get_component_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.get_component_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_component_policy)
         """
 
@@ -390,7 +395,7 @@ class imagebuilderClient:
         """
         Retrieves a container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_container_recipe)
         """
 
@@ -400,7 +405,7 @@ class imagebuilderClient:
         """
         Retrieves the policy for a container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_container_recipe_policy)
         """
 
@@ -410,7 +415,7 @@ class imagebuilderClient:
         """
         Gets a distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.get_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.get_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_distribution_configuration)
         """
 
@@ -418,7 +423,7 @@ class imagebuilderClient:
         """
         Gets an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.get_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.get_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image)
         """
 
@@ -426,7 +431,7 @@ class imagebuilderClient:
         """
         Gets an image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.get_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.get_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_pipeline)
         """
 
@@ -434,7 +439,7 @@ class imagebuilderClient:
         """
         Gets an image policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.get_image_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.get_image_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_policy)
         """
 
@@ -442,7 +447,7 @@ class imagebuilderClient:
         """
         Gets an image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_recipe)
         """
 
@@ -452,7 +457,7 @@ class imagebuilderClient:
         """
         Gets an image recipe policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_recipe_policy)
         """
 
@@ -462,7 +467,7 @@ class imagebuilderClient:
         """
         Gets an infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.get_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.get_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_infrastructure_configuration)
         """
 
@@ -485,7 +490,7 @@ class imagebuilderClient:
         """
         Imports a component and transforms its data into a component document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.import_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.import_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#import_component)
         """
 
@@ -495,7 +500,7 @@ class imagebuilderClient:
         """
         Returns the list of component build versions for the specified semantic version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_component_build_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_component_build_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_component_build_versions)
         """
 
@@ -511,7 +516,7 @@ class imagebuilderClient:
         """
         Returns the list of component build versions for the specified semantic version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_components)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_components)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_components)
         """
 
@@ -526,7 +531,7 @@ class imagebuilderClient:
         """
         Returns a list of container recipes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_container_recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_container_recipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_container_recipes)
         """
 
@@ -540,7 +545,7 @@ class imagebuilderClient:
         """
         Returns a list of distribution configurations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_distribution_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_distribution_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_distribution_configurations)
         """
 
@@ -555,7 +560,7 @@ class imagebuilderClient:
         """
         Returns a list of image build versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_image_build_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_image_build_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_build_versions)
         """
 
@@ -566,7 +571,7 @@ class imagebuilderClient:
         List the Packages that are associated with an Image Build Version, as determined
         by AWS Systems Manager Inventory at build time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_image_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_image_packages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_packages)
         """
 
@@ -581,7 +586,7 @@ class imagebuilderClient:
         """
         Returns a list of images created by the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipeline_images)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipeline_images)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_pipeline_images)
         """
 
@@ -595,7 +600,7 @@ class imagebuilderClient:
         """
         Returns a list of image pipelines.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_pipelines)
         """
 
@@ -610,7 +615,7 @@ class imagebuilderClient:
         """
         Returns a list of image recipes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_image_recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_image_recipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_recipes)
         """
 
@@ -627,7 +632,7 @@ class imagebuilderClient:
         """
         Returns the list of images that you have access to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_images)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_images)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_images)
         """
 
@@ -641,7 +646,7 @@ class imagebuilderClient:
         """
         Returns a list of infrastructure configurations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_infrastructure_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_infrastructure_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_infrastructure_configurations)
         """
 
@@ -649,7 +654,7 @@ class imagebuilderClient:
         """
         Returns the list of tags for the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_tags_for_resource)
         """
 
@@ -659,7 +664,7 @@ class imagebuilderClient:
         """
         Applies a policy to a component.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.put_component_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.put_component_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_component_policy)
         """
 
@@ -669,7 +674,7 @@ class imagebuilderClient:
         """
         Applies a policy to a container image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.put_container_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.put_container_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_container_recipe_policy)
         """
 
@@ -677,7 +682,7 @@ class imagebuilderClient:
         """
         Applies a policy to an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.put_image_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.put_image_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_image_policy)
         """
 
@@ -687,7 +692,7 @@ class imagebuilderClient:
         """
         Applies a policy to an image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.put_image_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.put_image_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_image_recipe_policy)
         """
 
@@ -697,7 +702,7 @@ class imagebuilderClient:
         """
         Manually triggers a pipeline to create an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.start_image_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.start_image_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#start_image_pipeline_execution)
         """
 
@@ -705,7 +710,7 @@ class imagebuilderClient:
         """
         Adds a tag to a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#tag_resource)
         """
 
@@ -713,7 +718,7 @@ class imagebuilderClient:
         """
         Removes a tag from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#untag_resource)
         """
 
@@ -728,7 +733,7 @@ class imagebuilderClient:
         """
         Updates a new distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.update_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.update_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update_distribution_configuration)
         """
 
@@ -750,7 +755,7 @@ class imagebuilderClient:
         """
         Updates an image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.update_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.update_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update_image_pipeline)
         """
 
@@ -773,6 +778,6 @@ class imagebuilderClient:
         """
         Updates a new infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/imagebuilder.html#imagebuilder.Client.update_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/imagebuilder.html#imagebuilder.Client.update_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update_infrastructure_configuration)
         """
